@@ -11,6 +11,9 @@ createGWAS <- getFromNamespace(x = "createGWAS", ns = "statgenGWAS")
 #' @keywords internal
 plot.GWAS <- getFromNamespace(x = "plot.GWAS", ns = "statgenGWAS")
 
+#' @keywords internal
+nearestPD <- getFromNamespace(x = "nearestPD", ns = "statgenGWAS")
+
 #' @keywords internal
 markers3DtoMat <- getFromNamespace(x = "markers3DtoMat", ns = "statgenIBD")
 
@@ -22,3 +25,9 @@ singleGenoPlot <- getFromNamespace(x = "singleGenoPlot", ns = "statgenIBD")
 
 #' @keywords internal
 pedPlot <- getFromNamespace(x = "pedPlot", ns = "statgenIBD")
+
+#' @keywords internal
+constructRinv <- getFromNamespace(x = "constructRinv", ns = "LMMsolver")
+
+#' @keywords internal
+sparseMixedModels <- getFromNamespace(x = "sparseMixedModels", ns = "LMMsolver")
